@@ -11,9 +11,14 @@ _ModelManagerType = create_linked_type_var(_RunManagerType, bound=ModelManager)
 
 class ModelFolder(RunFolder[_ModelManagerType]):
     _cls_run_manager: Type[_ModelManagerType]
+    _prefix: str
 
     def __init__(self, models_folder: str, prefix: str, localize_via_run_name: bool = False):
-        super(ModelFolder, self).__init__(models_folder, f"{prefix}-$", localize_via_run_name=localize_via_run_name)
+        self._prefix = prefix
+        super(ModelFolder, self).__init__(models_folder, f"{prefix}-$[-*]", localize_via_run_name=localize_via_run_name)
+
+    def get_prefix(self) -> str:
+        return self._prefix
 
     def open_run(self, run_name_or_id: Union[str, int]) -> _ModelManagerType:
         run_name = self.resolve_run_name(run_name_or_id)
